﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Collections.ObjectModel;
using Infragistics.Controls.Charts;
using Infragistics.Controls;

namespace XamDataChartsZoomBarSync
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
            this.DataContext = ChartData.GenerateData(20);

            LineSeries newSer = new LineSeries();
            newSer.MarkerType = MarkerType.None;
            newSer.ItemsSource = this.DataContext as ObservableCollection<ChartData>;
            newSer.ValueMemberPath = "Value1";
            newSer.XAxis = commonXAxis;
            newSer.YAxis = priceYAxis;
            chart.Series.Add(newSer);

            ColumnSeries volSer = new ColumnSeries();
            volSer.MarkerType = MarkerType.None;
            volSer.ItemsSource = this.DataContext as ObservableCollection<ChartData>;
            volSer.ValueMemberPath = "Value2";
            volSer.XAxis = commonXAxis;
            volSer.YAxis = volumeYAxis;
            volSer.XAxis.ItemsSource = this.DataContext as ObservableCollection<ChartData>;
            volChart.Series.Add(volSer);

            LineSeries previewSeries = new LineSeries();
            previewSeries.MarkerType = MarkerType.None;
            previewSeries.ItemsSource = this.DataContext as ObservableCollection<ChartData>;
            previewSeries.ValueMemberPath = "Value1";
            previewSeries.XAxis = xmPreviewXAxis;
            previewSeries.YAxis = xmPreviewYAxis;
            previewSeries.XAxis.ItemsSource = this.DataContext as ObservableCollection<ChartData>;
            xmPreviewDataChart.Series.Add(previewSeries);
        }

        private void Window_Loaded(object sender, RoutedEventArgs e)
        {
            if (xmZoombar != null && this.chart != null)
            {
                Binding binding = new Binding
                {
                    Source = this.chart,
                    Path = new PropertyPath("HorizontalZoombar.Range"),
                    Mode = BindingMode.TwoWay
                };
                xmZoombar.SetBinding(XamZoombar.RangeProperty, binding);
                xmZoombar.Range = new Range { Minimum = 0.3, Maximum = 1 };
                chart.HorizontalZoomable = false;
            }
        }
    }

    public class ChartData
    {
        public DateTime Date { get; set; }
        public double Value1 { get; set; }
        public double Value2 { get; set; }
        public double Value3 { get; set; }

        public static ObservableCollection<ChartData> GenerateData(int count)
        {
            ObservableCollection<ChartData> data = new ObservableCollection<ChartData>();

            Random r = new Random();

            ChartData data0 = new ChartData
            {
                Date = DateTime.Now,
                Value1 = r.Next(20, 40),
                Value2 = r.Next(20, 40),
                Value3 = r.Next(20, 40),
            };

            data.Add(data0);

            for (int i = 1; i < count; i++)
            {
                ChartData dat = new ChartData
                {
                    Date = DateTime.Now.AddDays(i),
                };

                if (r.NextDouble() > .5)
                {
                    dat.Value1 = data[i - 1].Value1 + r.NextDouble();
                    dat.Value2 = data[i - 1].Value2 + r.NextDouble();
                    dat.Value3 = data[i - 1].Value3 + r.NextDouble();
                }
                else
                {
                    dat.Value1 = data[i - 1].Value1 - r.NextDouble();
                    dat.Value2 = data[i - 1].Value2 - r.NextDouble();
                    dat.Value3 = data[i - 1].Value3 - r.NextDouble();
                }

                data.Add(dat);
            }

            return data;
        }
    }
}
